Gramex
======

.. image:: https://travis-ci.org/gramener/gramex.svg?branch=dev
    :target: https://travis-ci.org/gramener/gramex
.. image:: https://badge.fury.io/py/gramex.svg
    :target: https://badge.fury.io/py/gramex

Gramex is a low-code data solutions platform: a fast way to build data-based web apps with less
code.

Gramex takes a component based approach building data apps. (Like LEGO bricks.)
This needs fewer steps, takes less time, and builds apps with fewer bugs.

`Examples of public data apps built on Gramex <https://gramener.com/solutions/>`_

Getting Started
---------------

- `Online Documentation <https://gramener.com/gramex/guide/>`_
- `Set up Gramex <https://gramener.com/gramex/guide/install/>`_

Contributing
------------

**Need help?**
`Browse the issues <https://github.com/gramener/gramex/issues>`_

**Want to report a bug or request a feature?**
`Open an issue <https://github.com/gramener/gramex/issues/new>`_.
If it is a security issue, please email to security@gramener.com, rather
than publicly sharing the vulnerability.

**Want to fix a bug or add a feature?**
`Read the contributing guidelines <https://gramener.com/gramex/guide/contributing/>`_.
Fork this repo, make changes, test it, and send a pull request.


License
-------

`MIT LICENSE <https://opensource.org/licenses/MIT>`_

Gramener also offers a Gramex Enterprise Server with support, securty &
enterprise deployment. Contact license@gramener.com for details.
